==> sqlmath-2023.9.25.tar.gz: sqlmath-2023.9.25/sqlmath_wrapper_wasm.js <==
// The MIT License (MIT)
//
// Copyright (c) 2021 Kai Zhu
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.


/*jslint beta, browser, devel, nomen, subscript*/
/*global
    AsciiToString
    FS
    HEAPU8
    Module
    _sqlite3_free
    _sqlite3_initialize
    _sqlite3_malloc
    cwrap
*/


// init debugInline
let debugInline = (function () {
    let __consoleError = function () {
        return;
    };
    function debug(...argv) {

// This function will print <argv> to stderr and then return <argv>[0].

        __consoleError("\n\ndebugInline");
        __consoleError(...argv);
        __consoleError("\n");
        return argv[0];
    }
    debug(); // Coverage-hack.
    __consoleError = console.error; //jslint-ignore-line
    return debug;
}());

function noop(val) {

// This function will do nothing except return <val>.

    return val;
}

(async function () {
    let FILENAME_DBTMP = "/tmp/__dbtmp1";
    let JSBATON_ARGC = 16;
    let __dbFileImportOrExport;
    let jsbatonValueErrmsg;
    let jsbatonValueStringArgi;
    let onModulePostRun;
    let sqlite3_errmsg;

    function messageDispatch(data) {
        let argList = data["argList"];
        let baton = new Uint8Array(data["baton"] && data["baton"].buffer);
        let batonPtr = 0;
        let cFuncName = data["cFuncName"];
        let dbData = argList[4];
        let dbPtr = 0;
        let errcode = 0;
        let errmsg = "";
        let filename;
        let id = data.id;
        let modeExport = argList[2];
        switch (cFuncName) {
        case "_dbClose":
        case "_dbExec":
        case "_dbFileImportOrExport":
        case "_dbNoop":
        case "_dbOpen":
            // copy baton to wasm
            batonPtr = _sqlite3_malloc(baton.byteLength);
            data["batonPtr"] = batonPtr;
            HEAPU8.set(baton, batonPtr);
            switch (cFuncName) {
            case "_dbClose":
                filename = jsbatonValueStringArgi(batonPtr, 1);
                console.error(`_dbClose("${filename}")`);
                break;
            case "_dbFileImportOrExport":
                // import dbData
                if (!modeExport) {
                    FS.writeFile(FILENAME_DBTMP, new Uint8Array(dbData));
                }
                break;
            case "_dbOpen":
                filename = jsbatonValueStringArgi(batonPtr, 0);
                console.error(`_dbOpen("${filename}")`);
                break;
            }
            // call c-function
            Module[cFuncName](batonPtr);
            // init errmsg
            errmsg = jsbatonValueErrmsg(batonPtr);
            // update baton
            baton.set(new Uint8Array(
                HEAPU8.buffer,
                HEAPU8.byteOffset + batonPtr,
                1024
            ));
            baton = new BigInt64Array(baton.buffer, 4 + 4);
            baton.subarray(
                JSBATON_ARGC,
                2 * JSBATON_ARGC
            ).forEach(function (ptr, ii) {
                // ignore ArrayBuffer
                if (argList[ii] && (
                    argList[ii].constructor === ArrayBuffer
                    || (
                        typeof SharedArrayBuffer === "function"
                        && argList[ii].constructor === SharedArrayBuffer
                    )
                )) {
                    return;
                }
                ptr = Number(ptr);
                // init argList[ii] = argv[ii]
                if (ptr === 0) {
                    argList[ii] = baton[ii];
                // init argList[ii] = bufv[ii]
                } else {
                    argList[ii] = new ArrayBuffer(
                        Number(baton[ii])
                    );
                    new Uint8Array(argList[ii]).set(
                        HEAPU8.subarray(ptr, ptr + argList[ii].byteLength)
                    );
                    // cleanup ptr
                    _sqlite3_free(ptr);
                }
            });
            switch (!errmsg && cFuncName) {
            case "_dbFileImportOrExport":
                // export dbData
                if (modeExport) {
                    dbData = FS.readFile(FILENAME_DBTMP);
                    argList[4] = dbData.buffer;
                }
                break;
            case "_dbOpen":
                // import dbData
                if (dbData) {
                    FS.writeFile(FILENAME_DBTMP, new Uint8Array(dbData));
                    dbPtr = Number(argList[0]);
                    errcode = __dbFileImportOrExport(dbPtr, FILENAME_DBTMP, 0);
                    if (errcode) {
                        errmsg = sqlite3_errmsg(dbPtr);
                    }
                }
                break;
            }
            postMessage(
                {
                    "argList": argList,
                    "baton": new DataView(baton.buffer),
                    "cFuncName": cFuncName,
                    "errmsg": errmsg,
                    "id": id
                },
                // transfer arraybuffer without copying
                [
                    baton.buffer,
                    ...argList.filter(function (elem) {
                        return elem && elem.constructor === ArrayBuffer;
                    })
                ]
            );
            return;
        }
        throw new Error(`invalid cFuncName "${cFuncName}"`);
    }

    // init event-handling
    globalThis["onmessage"] = async function ({
        data
    }) {
        let cFuncName = data["cFuncName"];
        function cleanup() {
            // cleanup batonPtr
            _sqlite3_free(data["batonPtr"]);
            // cleanup FILENAME_DBTMP
            switch (cFuncName) {
            case "_dbFileImportOrExport":
            case "_dbOpen":
                try {
                    FS.unlink(FILENAME_DBTMP);
                } catch (ignore) {}
                break;
            }
        }
        await onModulePostRun;
        // reset batonPtr
        data["batonPtr"] = 0;
        try {
            await messageDispatch(data);
        } catch (err) {
            postMessage({
                "errmsg": err.stack,
                "id": data.id
            });
        } finally {
            cleanup();
        }
    };

    // init Module
    onModulePostRun = new Promise(function (resolve) {
        Module["postRun"] = resolve;
    });
    await onModulePostRun;
    __dbFileImportOrExport = cwrap(
        "__dbFileImportOrExport",
        "number",
        [
            "number", "string", "number"
        ]
    );
    jsbatonValueErrmsg = cwrap("jsbatonValueErrmsg", "string", [
        "number"
    ]);
    jsbatonValueStringArgi = cwrap("jsbatonValueStringArgi", "string", [
        "number", "number"
    ]);
    sqlite3_errmsg = cwrap("sqlite3_errmsg", "string", [
        "number"
    ]);

    // init sqlite
    _sqlite3_initialize();
}());

==> sqlmath-2024.1.21.tar.gz: sqlmath-2024.1.21/sqlmath_wrapper_wasm.js <==
// The MIT License (MIT)
//
// Copyright (c) 2021 Kai Zhu
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.


/*jslint beta, browser, devel, nomen, subscript*/
/*global
    AsciiToString
    FS
    HEAPU8
    Module
    _dbCall
    _jsbatonGetInt64
    _sqlite3_free
    _sqlite3_initialize
    _sqlite3_malloc
    cwrap
*/


// init debugInline
let debugInline = (function () {
    let __consoleError = function () {
        return;
    };
    function debug(...argv) {

// This function will print <argv> to stderr and then return <argv>[0].

        __consoleError("\n\ndebugInline");
        __consoleError(...argv);
        __consoleError("\n");
        return argv[0];
    }
    debug(); // Coverage-hack.
    __consoleError = console.error; //jslint-ignore-line
    return debug;
}());

function isExternalBuffer(buf) {

// This function will check if <buf> is ArrayBuffer.

    return buf && buf.constructor === ArrayBuffer;
}

function noop(val) {

// This function will do nothing except return <val>.

    return val;
}

(async function () {
    // cwrap string-based c-functions
    let dbFileLoadOrSave = cwrap("dbFileLoadOrSave", "number", [
        "number", "string", "number"
    ]);
    let jsbatonGetErrmsg = cwrap("jsbatonGetErrmsg", "string", ["number"]);
    let jsbatonGetString = cwrap("jsbatonGetString", "string", [
        "number", "number"
    ]);
    let sqlite3_errmsg = cwrap("sqlite3_errmsg", "string", ["number"]);

    let onModulePostRun; //jslint-ignore-line

    function messageDispatch(data) {
        let FILENAME_DBTMP = data["FILENAME_DBTMP"];
        let JSBATON_OFFSET_ALL = data["JSBATON_OFFSET_ALL"];
        let JSBATON_OFFSET_BUFV = data["JSBATON_OFFSET_BUFV"];
        let argList = data["argList"];
        let baton = new Uint8Array(data["baton"].buffer);
        let batonPtr = 0;
        let dbData = argList[4];
        let errcode = 0;
        let errmsg = "";
        let funcname = data["funcname"];
        let modeSave = argList[2];
        switch (funcname) {
        case "_dbClose":
        case "_dbExec":
        case "_dbFileLoad":
        case "_dbNoop":
        case "_dbOpen":
            // copy baton to wasm-memory
            batonPtr = _sqlite3_malloc(baton.byteLength);
            data["batonPtr"] = batonPtr;
            HEAPU8.set(baton, batonPtr);
            switch (funcname) {
            case "_dbClose":
                console.error(`_dbClose("${jsbatonGetString(batonPtr, 1)}")`);
                break;
            case "_dbFileLoad":
                // load dbData
                if (!modeSave) {
                    FS.writeFile(FILENAME_DBTMP, new Uint8Array(dbData));
                }
                break;
            case "_dbOpen":
                console.error(`_dbOpen("${jsbatonGetString(batonPtr, 0)}")`);
                break;
            }
            // call c-function
            _dbCall(batonPtr);
            // init errmsg
            errmsg = jsbatonGetErrmsg(batonPtr);
            // update baton from wasm-memory
            baton.set(HEAPU8.subarray(batonPtr, batonPtr + JSBATON_OFFSET_ALL));
            switch (!errmsg && funcname) {
            case "_dbExec":
                dbData = new BigInt64Array(baton.buffer, JSBATON_OFFSET_BUFV);
                argList[0] = HEAPU8.slice(
                    Number(dbData[0]),
                    Number(dbData[0] + dbData[1])
                ).buffer;
                _sqlite3_free(Number(dbData[0]));
                break;
            case "_dbFileLoad":
                // save dbData
                if (modeSave) {
                    dbData = FS.readFile(FILENAME_DBTMP);
                    argList[0] = dbData.buffer;
                    FS.unlink(FILENAME_DBTMP);
                }
                break;
            case "_dbOpen":
                // open dbData
                if (dbData) {
                    FS.writeFile(FILENAME_DBTMP, new Uint8Array(dbData));
                    dbData = Number(_jsbatonGetInt64(batonPtr, 0));
                    errcode = dbFileLoadOrSave(dbData, FILENAME_DBTMP, 0);
                    if (errcode) {
                        errmsg = sqlite3_errmsg(dbData);
                    }
                    FS.unlink(FILENAME_DBTMP);
                }
                break;
            }
            postMessage(
                {
                    "argList": argList,
                    "baton": new DataView(baton.buffer),
                    "errmsg": errmsg,
                    "funcname": funcname,
                    "id": data["id"]
                },
                // transfer arraybuffer without copying
                [baton.buffer, ...argList.filter(isExternalBuffer)]
            );
            return;
        }
        throw new Error(`invalid funcname "${funcname}"`);
    }

    // init event-handling
    globalThis["onmessage"] = async function ({
        data
    }) {
        await onModulePostRun;
        // reset batonPtr
        data["batonPtr"] = 0;
        try {
            await messageDispatch(data);
        } catch (err) {
            postMessage({
                "errmsg": err.stack,
                "id": data["id"]
            });
        } finally {
            // cleanup batonPtr
            _sqlite3_free(data["batonPtr"]);
        }
    };

    // init Module
    onModulePostRun = new Promise(function (resolve) {
        Module["postRun"] = resolve;
    });
    await onModulePostRun;

    // init sqlite
    _sqlite3_initialize();
}());
